Lib: colours_library
Lead dev: Eryk Malczyk

Installation process:
pip install colours_library

then

python3

import colours_library

colours_library.produce('path_to_image', integer(number of colours sorted by frequency))